"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
class Paginator {
    constructor(data) {
        this.perPage = 10;
        this.currentPage = 1;
        this.total = 0;
        this.firstPage = 1;
        Object.assign(this, data);
    }
    get isEmpty() {
        return this.total === 0;
    }
    get hasTotal() {
        return this.total > 0;
    }
    get hasMorePages() {
        return this.currentPage < this.lastPage;
    }
    get hasPages() {
        return this.total > this.perPage;
    }
    get lastPage() {
        return Math.ceil(this.total / this.perPage);
    }
    get offset() {
        return this.perPage * (this.currentPage - 1);
    }
}
class Paginate {
    constructor(data, limit) {
        this.data = data;
        this.meta = new Paginator({ perPage: limit, total: data.length });
    }
    page(page) {
        this.meta.currentPage = page;
        return this;
    }
    get metaObject() {
        return {
            perPage: this.meta.perPage,
            currentPage: this.meta.currentPage,
            total: this.meta.total,
            firstPage: this.meta.firstPage,
            isEmpty: this.meta.isEmpty,
            hasTotal: this.meta.hasTotal,
            hasMorePages: this.meta.hasMorePages,
            hasPages: this.meta.hasPages,
            lastPage: this.meta.lastPage,
            offset: this.meta.offset,
        };
    }
    get all() {
        return {
            data: this.data.slice(this.meta.offset, this.meta.perPage),
            meta: this.metaObject,
        };
    }
}
exports.default = Paginate;
//# sourceMappingURL=Paginator.js.map